@@ -18,7 +18,7 @@ KW_JWT_HEADER_TYPE = 'JWT_HEADER_TYPE'
 UNAUTHORIZED_MESSAGE = 'Unauthorized'
 FORBIDDEN_MESSAGE = 'Frobidden'
 INVALID_SESSION_MESSAGE = 'Invalid session'
-INVALID_API_KEY_MESSAGE = 'Invalid apiKey'
+INVALID_API_KEY_MESSAGE = 'Invalid api key'
 
 ACCESS_VALUE_TYPE = 'access'
 REFRESH_VALUE_TYPE = 'refresh'
